import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/analytics_date_picker_bloc/analytics_date_picker_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/energy_consumption_by_phases/energy_consumption_by_phases_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/energy_consumption_per_device/energy_consumption_per_device_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/power_clamp_info/power_clamp_info_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/realtime_device_changes/realtime_device_changes_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/total_energy_consumption/total_energy_consumption_bloc.dart';
import 'package:syncrow_web/pages/analytics/params/get_energy_consumption_by_phases_param.dart';
import 'package:syncrow_web/pages/analytics/params/get_energy_consumption_per_device_param.dart';
import 'package:syncrow_web/pages/analytics/params/get_total_energy_consumption_param.dart';

abstract final class FetchEnergyManagementDataHelper {
  const FetchEnergyManagementDataHelper._();

  static const String _powerClampId = 'cb71d6ad-6e29-4eaa-ae3e-1a0d1c5f60fa';

  static void loadEnergyManagementData(
    BuildContext context, {
    required String communityId,
    required String spaceId,
    DateTime? selectedDate,
  }) {
    if (communityId.isEmpty && spaceId.isEmpty) {
      clearAllData(context);
      return;
    }

    final datePickerState = context.read<AnalyticsDatePickerBloc>().state;
    final selectedDate0 = selectedDate ?? datePickerState.monthlyDate;

    loadTotalEnergyConsumption(
      context,
      selectedDate: selectedDate0,
      communityId: communityId,
      spaceId: spaceId,
    );

    loadEnergyConsumptionByPhases(context, selectedDate: selectedDate);

    loadEnergyConsumptionPerDevice(context);
    loadRealtimeDeviceChanges(context);
    loadPowerClampInfo(context);
  }

  static void loadEnergyConsumptionByPhases(
    BuildContext context, {
    DateTime? selectedDate,
  }) {
    final param = GetEnergyConsumptionByPhasesParam(
      startDate: selectedDate,
      spaceId: '',
    );
    context.read<EnergyConsumptionByPhasesBloc>().add(
          LoadEnergyConsumptionByPhasesEvent(param: param),
        );
  }

  static void loadTotalEnergyConsumption(
    BuildContext context, {
    DateTime? selectedDate,
    required String communityId,
    required String spaceId,
  }) {
    final param = GetTotalEnergyConsumptionParam(
      spaceId: spaceId,
      communityId: communityId,
      monthDate: selectedDate,
    );
    context.read<TotalEnergyConsumptionBloc>().add(
          TotalEnergyConsumptionLoadEvent(param: param),
        );
  }

  static void loadEnergyConsumptionPerDevice(BuildContext context) {
    const param = GetEnergyConsumptionPerDeviceParam();
    context.read<EnergyConsumptionPerDeviceBloc>().add(
          const LoadEnergyConsumptionPerDeviceEvent(param),
        );
  }

  static void loadPowerClampInfo(BuildContext context) {
    context.read<PowerClampInfoBloc>().add(
          const LoadPowerClampInfoEvent(_powerClampId),
        );
  }

  static void loadRealtimeDeviceChanges(BuildContext context) {
    context.read<RealtimeDeviceChangesBloc>().add(
          const RealtimeDeviceChangesStarted(_powerClampId),
        );
  }

  static void clearAllData(BuildContext context) {
    context.read<RealtimeDeviceChangesBloc>().add(
          const RealtimeDeviceChangesClosed(),
        );

    context.read<PowerClampInfoBloc>().add(
          const ClearPowerClampInfoEvent(),
        );

    context.read<EnergyConsumptionPerDeviceBloc>().add(
          const ClearEnergyConsumptionPerDeviceEvent(),
        );

    context.read<TotalEnergyConsumptionBloc>().add(
          const ClearTotalEnergyConsumptionEvent(),
        );

    context.read<EnergyConsumptionByPhasesBloc>().add(
          const ClearEnergyConsumptionByPhasesEvent(),
        );
  }
}
